<template>
    <AdminMainLayout>
        <div class="row g-4">
            <div class="col-md-3" v-for="(item, index) in cards" :key="index">
                <div class="card bg-secondary text-white position-relative overflow-hidden">
                    <div class="p-3 position-relative z-1">
                        <div class="d-flex justify-content-between align-items-start">
                            <div>
                                <h6 class="text-white">{{ item.title }}</h6>
                                <h2 class="fw-semibold text-white">{{ item.value }}</h2>
                            </div>
                            <div
                                class="rounded-circle d-flex align-items-center justify-content-center"
                                :class="item.bgClass"
                                style="width: 48px; height: 48px;"
                            >
                                <i :class="item.icon" class="fs-3 text-white"></i>
                            </div>
                        </div>
                        <div class="mt-3">
                            <p class="text-white mb-0">{{ item.description }}</p>
                        </div>
                    </div>
                </div>
            </div>
        </div>
        <div class="row g-4 mt-4">
            <div class="col-md-12">
                <div class="card card-statistic p-3">
                    <div class="d-flex justify-content-between align-items-center">
                        <h5>Statistik Lamaran Bulan ({{ moment(`${selectedYear}-${selectedMonth}-01`).format("MMMM YYYY") }})</h5>
                        <div class="d-flex gap-2 w-25">
                            <BaseDropDown placeholder="Pilih Tahun" :options="availableYear" label="Tahun" class="w-100" v-model="selectedYear" />
                            <BaseDropDown placeholder="Pilih Bulan" :options="availableMonth" label="Bulan" class="w-100" v-model="selectedMonth" />
                        </div>
                    </div>
                    <apexchart type="line" :options="lineOptions" :series="lineSeries" height="350"></apexchart>
                </div>
            </div>
            <div class="col-md-12">
                <div class="card card-statistic p-3">
                    <h5>Perusahaan Favorit</h5>
                    <apexchart type="bar" :options="barOptions" :series="barSeries" height="350"></apexchart>
                </div>
            </div>
        </div>
    </AdminMainLayout>
</template>

<script setup>
import AdminMainLayout from "@/Layouts/AdminMainLayout.vue";
import BaseDropDown from "@/Components/Forms/BaseDropDown.vue";
import moment from "moment";
import { ref, computed, watch } from "vue";
import { router } from "@inertiajs/vue3";
import ApexCharts from "vue3-apexcharts";

const props = defineProps({
    data: Object,
    statistics: Object,
    list_year: Array,
    meta: Object,
});

const cards = [
    { title: 'Total Lowongan', value: props.data.total.vacancy, icon: 'ti ti-briefcase', bgClass: 'bg-success', description: 'Lowongan tersedia untuk alumni. 🎯' },
    { title: 'Total Mitra DU/DI', value: props.data.total.company, icon: 'ti ti-building', bgClass: 'bg-primary', description: 'Mitra kerja sama dengan sekolah. 🤝' },
    { title: 'Total Jurusan', value: props.data.total.major, icon: 'ti ti-book', bgClass: 'bg-danger', description: 'Program keahlian yang tersedia. 📚' },
    { title: 'Total Alumni', value: props.data.total.user, icon: 'ti ti-users', bgClass: 'bg-warning', description: 'Data alumni yang terdaftar. 🎓' }
];

const availableMonth = [...Array(12)].map((_, i) => ({ label: moment().month(i).format('MMMM'), value: String(i + 1).padStart(2, '0') }));

const availableYear = computed(() => props.list_year.map((year) => ({ label: year.year, value: year.year })));

const selectedYear = ref(props.meta.year);
const selectedMonth = ref(props.meta.month);

watch([selectedYear, selectedMonth], ([year, month]) => {
    router.get("/backoffice/admin/dashboard", { year, month });
});

const lineSeries = [{
    name: 'Jumlah Lamaran',
    data: props.statistics.monthly.map(stat => stat.total)
}];

const lineOptions = {
    chart: { height: 350, type: 'line' },
    xaxis: { categories: props.statistics.monthly.map(stat => moment(stat.date).format('DD')) }
};

const barSeries = props.statistics.favorite_apply_company.map(company => ({
    name: company.name,
    data: [company.total_applied]
}));

const barOptions = {
    chart: { height: 350, type: 'bar' },
    xaxis: { categories: ['Perusahaan Favorit'] }
};
</script>

<style scoped>
.card.bg-secondary::before,
.card.bg-secondary::after {
    content: "";
    position: absolute;
    border-radius: 50%;
    background: #2b2f5c;
    opacity: 0.5;
    z-index: 0;
}

.card.bg-secondary::before {
    width: 210px;
    height: 210px;
    top: -125px;
    right: -15px;
}

.card.bg-secondary::after {
    width: 210px;
    height: 210px;
    top: -85px;
    right: -95px;
}
.card-statistic {
    height: 30rem;
}
</style>
